==> estateplat-common-1.2.4-20201022.054839-475-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxWwSqxxJtcy.java <==
package cn.gtmap.estateplat.model.exchange.share;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:chenjia@gtmap.cn">chenjia</a>
 * @version 1.0, 2020/10/22
 * @description 共享家庭成员
 */
@Table(name = "gx_ww_sqxx_jtcy")
public class GxWwSqxxJtcy implements Serializable {
    @Id
    private String jtcyid;//家庭成员ID

    private String qlrid;//权利人ID

    private String jtcymc;//家庭成员名称

    private String jycyzjzl;//身份证件种类

    private String jtcyzjh;//证件号

    private String txdz;//通讯地址

    private String xb;//性别

    private String lxdh;//联系电话

    private Integer xh;//序号

    private String jtgx;//与户主关系

    public String getJtcyid() {
        return jtcyid;
    }

    public void setJtcyid(String jtcyid) {
        this.jtcyid = jtcyid;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getJtcymc() {
        return jtcymc;
    }

    public void setJtcymc(String jtcymc) {
        this.jtcymc = jtcymc;
    }

    public String getJycyzjzl() {
        return jycyzjzl;
    }

    public void setJycyzjzl(String jycyzjzl) {
        this.jycyzjzl = jycyzjzl;
    }

    public String getJtcyzjh() {
        return jtcyzjh;
    }

    public void setJtcyzjh(String jtcyzjh) {
        this.jtcyzjh = jtcyzjh;
    }

    public String getTxdz() {
        return txdz;
    }

    public void setTxdz(String txdz) {
        this.txdz = txdz;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public String getJtgx() {
        return jtgx;
    }

    public void setJtgx(String jtgx) {
        this.jtgx = jtgx;
    }
}

==> estateplat-common-1.2.4-20220722.085619-1074-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxWwSqxxJtcy.java <==
package cn.gtmap.estateplat.model.exchange.share;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:chenjia@gtmap.cn">chenjia</a>
 * @version 1.0, 2020/10/22
 * @description 共享家庭成员
 */
@Table(name = "gx_ww_sqxx_jtcy")
public class GxWwSqxxJtcy implements Serializable {
    @Id
    private String jtcyid;//家庭成员ID

    private String qlrid;//权利人ID

    private String jtcymc;//家庭成员名称

    private String jtcyzjzl;//身份证件种类

    private String jtcyzjh;//证件号

    private String txdz;//通讯地址

    private String xb;//性别

    private String lxdh;//联系电话

    private Integer xh;//序号

    private String jtgx;//与户主关系

    public String getJtcyid() {
        return jtcyid;
    }

    public void setJtcyid(String jtcyid) {
        this.jtcyid = jtcyid;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getJtcymc() {
        return jtcymc;
    }

    public void setJtcymc(String jtcymc) {
        this.jtcymc = jtcymc;
    }

    public String getJtcyzjzl() {
        return jtcyzjzl;
    }

    public void setJtcyzjzl(String jtcyzjzl) {
        this.jtcyzjzl = jtcyzjzl;
    }

    public String getJtcyzjh() {
        return jtcyzjh;
    }

    public void setJtcyzjh(String jtcyzjh) {
        this.jtcyzjh = jtcyzjh;
    }

    public String getTxdz() {
        return txdz;
    }

    public void setTxdz(String txdz) {
        this.txdz = txdz;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }

    public String getJtgx() {
        return jtgx;
    }

    public void setJtgx(String jtgx) {
        this.jtgx = jtgx;
    }
}
